@@ -1,3 +1,4 @@
+#[cfg(not(feature = "paris"))]
 use log::*;
 use simplelog::*;
 
@@ -5,9 +6,14 @@ use std::fs::File;
 
 fn main() {
     CombinedLogger::init(vec![
-        #[cfg(feature = "term")]
-        TermLogger::new(LevelFilter::Warn, Config::default(), TerminalMode::Mixed).unwrap(),
-        #[cfg(not(feature = "term"))]
+        #[cfg(feature = "termcolor")]
+        TermLogger::new(
+            LevelFilter::Warn,
+            Config::default(),
+            TerminalMode::Mixed,
+            ColorChoice::Auto,
+        ),
+        #[cfg(not(feature = "termcolor"))]
         SimpleLogger::new(LevelFilter::Warn, Config::default()),
         WriteLogger::new(
             LevelFilter::Info,
